require 'builder_quill_content/version'
require 'json'
require 'convert_inline'

class BuilderQuillContent
  class Error < StandardError; end
  # Your code goes here...

  attr_accessor :input, :args

  EMBED_KEYS = %w[wk-image wk-youtube wk-tweet wk-instagram wk-divider waku-post wk-maps].freeze

  def initialize(input, args = {})
    @input = input
    @args  = args
    @line  = @content = ''
  end

  def to_html
    content_json = JSON.parse(@input)

    while content_json.length.positive?
      node = content_json.shift

      if node['insert'] == "\n"
        end_of_line(node['attributes'])
      elsif node['insert'].include?("\n")
        break_line(node['insert'])
      else
        inline(node)
      end
    end

    @content += @line unless @line.strip.empty?
    @content.gsub('</ul><ul>', '')
  rescue JSON::ParserError
    'No content'
  end

  def end_of_line(attributes)
    @content += attributes.nil? ? "<p>#{@line}</p>" : ConvertInline.new({ 'insert' => @line, 'attributes' => attributes }, args).convert
    @line = ''
  end

  def break_line(insert)
    insert.split(/(?<=\n)/).each do |text|
      if text.end_with?("\n")
        @content += "<p>#{@line}#{text.delete("\n")}</p>"
        @line = ''
      else
        @line += text
      end
    end
  end

  def inline(node)
    embed_node?(node) ? @content += ConvertInline.new(node, args).convert : @line += ConvertInline.new(node, args).convert
  end

  def embed_node?(node)
    return false if node['insert'].is_a?(String)

    node['insert'].keys.find { |k| EMBED_KEYS.include?(k) }
  end
end
