class ConvertInline
  class Error < StandardError; end
  # Your code goes here...

  attr_accessor :node, :insert, :attributes, :args

  def initialize(node, args = {})
    @node       = node
    @insert     = @node['insert']
    @attributes = @node['attributes']
    @args       = args
  end

  def convert
    return @insert if @insert.is_a?(String) && @attributes.nil?

    if @insert.is_a?(String)
      @attributes.each_key { |attr| @insert = send(attr) }
    else
      @insert = @insert.keys.first == 'wk-image' ? image : embed(@insert.keys.first)
    end

    @insert
  rescue NoMethodError
    @insert
  end

  private

  def italic
    "<em>#{@insert}</em>"
  end

  def bold
    "<strong>#{@insert}</strong>"
  end

  def header
    "<h#{@attributes['header']}>#{@insert}</h#{@attributes['header']}>"
  end

  def blockquote
    "<blockquote>#{@insert}</blockquote>"
  end

  def link
    '<a href="' << @attributes['link'] << '" target="_blank">' << @insert << '</a>'
  end

  def list
    "<ul><li>#{@insert}</li></ul>"
  end

  def embed(key)
    return '<hr>' if key == 'wk-divider'

    '<div data-id="' << key << '" data-src="' << @insert[key] << '"></div>'
  end

  def image
    invalid_cap = @insert['wk-image']['caption'].nil? || @insert['wk-image']['caption'].strip.empty?
    img_src     = @insert['wk-image']['src'] || @attributes['src'] || @insert['wk-image']
    img_cap     = invalid_cap ? '' : @insert['wk-image']['caption']
    img_alt     = invalid_cap ? args[:title] : @insert['wk-image']['caption']
    return '' if img_src.nil?

    data = '<figure class="post-content-image-container">'
    data << '<img class="post-content-image lazy blur" data-src="' << img_src << '" alt="' << img_alt << '">'
    data << '<figcaption class="post-image-caption u-text-center">' << img_cap << '</figcaption>'
    data << '</figure>'
    data
  end
end
